==> jcjt-cost-impl-3.0.0-20220916.095347-14-sources.jar: com/ejianc/business/cost/bean/DatasummaryEntity.java <==
package com.ejianc.business.cost.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 数据汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_data_summary")
public class DatasummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_time")
    private Date productTime; // 生产日期
    @TableField(value="production_mixture_name")
    private String productionMixtureName; // 生产配比名称
    @TableField(value="production_mixture_product_name")
    private String productionMixtureProductName; // 生产配比产品名称
    @TableField(value="production_mixture_id")
    private Long productionMixtureId; // 生产配比id
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="datasummarydetailService",pidName = "mid")//此处有pid="xxx"，默认值pid="pid"
    private List<DatasummarydetailEntity> datasummarydetailList = new ArrayList<>(); // 数据汇总明细表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Date getProductTime() {
        return productTime;
    }

    public void setProductTime(Date productTime) {
        this.productTime = productTime;
    }
    public String getProductionMixtureName() {
        return productionMixtureName;
    }

    public void setProductionMixtureName(String productionMixtureName) {
        this.productionMixtureName = productionMixtureName;
    }
    public String getProductionMixtureProductName() {
        return productionMixtureProductName;
    }

    public void setProductionMixtureProductName(String productionMixtureProductName) {
        this.productionMixtureProductName = productionMixtureProductName;
    }
    public Long getProductionMixtureId() {
        return productionMixtureId;
    }

    public void setProductionMixtureId(Long productionMixtureId) {
        this.productionMixtureId = productionMixtureId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
    public List<DatasummarydetailEntity> getDatasummarydetailList() {
        return datasummarydetailList;
    }

    public void setDatasummarydetailList(List<DatasummarydetailEntity> datasummarydetailList) {
        this.datasummarydetailList = datasummarydetailList;
    }
}

==> jcjt-cost-impl-3.0.0-20221013.074219-33-sources.jar: com/ejianc/business/cost/bean/DatasummaryEntity.java <==
package com.ejianc.business.cost.bean;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.ArrayList;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 数据汇总
 * 
 * @author generator
 * 
 */
 @TableName("ejc_production_data_summary")
public class DatasummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="product_id")
    private Long productId; // 产品id
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="unit_id")
    private Long unitId; // 机组id
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_time")
    private Date productTime; // 生产日期
    @TableField(value="production_mixture_name")
    private String productionMixtureName; // 生产配比名称
    @TableField(value="production_mixture_product_name")
    private String productionMixtureProductName; // 生产配比产品名称
    @TableField(value="production_mixture_id")
    private Long productionMixtureId; // 生产配比id
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="production_sum")
    private BigDecimal productionSum; // 产量
    
    @TableField(exist=false)
    @SubEntity(serviceName="datasummarydetailService",pidName = "mid")//此处有pid="xxx"，默认值pid="pid"
    private List<DatasummarydetailEntity> datasummarydetailList = new ArrayList<>(); // 数据汇总明细表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Date getProductTime() {
        return productTime;
    }

    public void setProductTime(Date productTime) {
        this.productTime = productTime;
    }
    public String getProductionMixtureName() {
        return productionMixtureName;
    }

    public void setProductionMixtureName(String productionMixtureName) {
        this.productionMixtureName = productionMixtureName;
    }
    public String getProductionMixtureProductName() {
        return productionMixtureProductName;
    }

    public void setProductionMixtureProductName(String productionMixtureProductName) {
        this.productionMixtureProductName = productionMixtureProductName;
    }
    public Long getProductionMixtureId() {
        return productionMixtureId;
    }

    public void setProductionMixtureId(Long productionMixtureId) {
        this.productionMixtureId = productionMixtureId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    
    public List<DatasummarydetailEntity> getDatasummarydetailList() {
        return datasummarydetailList;
    }

    public void setDatasummarydetailList(List<DatasummarydetailEntity> datasummarydetailList) {
        this.datasummarydetailList = datasummarydetailList;
    }

    public BigDecimal getProductionSum() {
        return productionSum;
    }

    public void setProductionSum(BigDecimal productionSum) {
        this.productionSum = productionSum;
    }
}
